@@ -2,7 +2,7 @@ from sylo.args import get_arguments
 from sylo.timer import run
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     args = get_arguments()
     run(args)
